@@ -71,11 +71,7 @@ function in the variable `loopy--flag-settings'."
                         when (memq definition aliases)
                         return orig)
                (and (map-contains-key loopy-parsers definition)
-                    definition)
-               (when-let* ((orig (gethash definition loopy--obsolete-aliases)))
-                 (warn "`loopy': `%s' is an obsolete built-in alias of `%s'.  It will be removed in the future.  To add it as a custom alias, add it to `loopy-parsers'."
-                       definition orig)
-                 orig))))
+                    definition))))
       (if (eq alias true-name)
           (error "Can't alias name to itself: `%s' -> `%s' -> ... -> `%s'"
                  alias definition true-name)
@@ -102,50 +98,6 @@ Definition must exist.  Neither argument need be quoted."
   `(loopy--defalias-1 (quote ,(loopy--get-quoted-symbol alias))
                       (quote ,(loopy--get-quoted-symbol definition))))
 
-(defvar loopy--obsolete-aliases
-  #s(hash-table
-     test eq
-     data ( across        array
-            arrayf        array-ref
-            arrayingf     array-ref
-            stringf       array-ref
-            stringingf    array-ref
-            across-ref    array-ref
-            group         command-do
-            on            cons
-            in            list
-            listf         list-ref
-            listingf      list-ref
-            in-ref        list-ref
-            mapf          map-ref
-            mappingf      map-ref
-            num           numbers
-            nums          numbers
-            nums-down     numbers-down
-            numdown       numbers-down
-            num-down      numbers-down
-            numsdown      numbers-down
-            nums-up       numbers-up
-            numup         numbers-up
-            num-up        numbers-up
-            numsup        numbers-up
-            exprs         set
-            expr          set
-            prev          set-prev
-            prev-expr     set-prev
-            elements      sequence
-            sequencei     sequence-index
-            seqi          sequence-index
-            listi         sequence-index
-            arrayi        sequence-index
-            stringi       sequence-index
-            seqf          seq-ref
-            seqingf       seq-ref
-            sequencef     sequence-ref
-            sequencingf   sequence-ref
-            elements-ref  sequence-ref))
-  "Aliases to be removed from the documentation.")
-
 (defun loopy--expression-parser-map-p (obj)
   "Return when OBJ has the correct data for `loopy-expression-parsers'."
   (and (mapp obj)
@@ -473,14 +425,20 @@ This is used to check for errors with the `at' command.")
 (defvar loopy--with-vars nil
   "With Forms are variables explicitly created using the `with' keyword.
 
-This is a list of ((VAR1 VAL1) (VAR2 VAL2) ...).  If VAR is a
-sequence, then it will be destructured.  How VAR and VAL are
-used, as well as how the bindings are expanded into the loop's
-surrounding code, is determined by the destructuring system being
-used.
+This is a list of the form (VARIABLES BINDING-FUNCTION).  VARIABLES
+is a list of symbols naming which variables are found in the bindings,
+including destructured bindings.  BINDING-FUNCTION is a function
+that will receive code to be wrapped in a `let'-like form
+and should return an expression binding the VARIABLES and setting
+their values.
 
 They are created by passing (with (VAR1 VAL1) (VAR2 VAL2) ...) to
-`loopy'.")
+`loopy'.
+
+Because it can affect expansion of the loop commands,
+`loopy--with-vars' is by `loopy--process-special-arg-with',
+which uses `loopy--destructure-for-with-vars' and the destructuring
+flags found by `loopy--process-special-arg-flag'.")
 
 (defvar loopy--without-vars nil
   "A list of variables that `loopy' won't try to initialize.
@@ -787,12 +745,8 @@ This list is mainly fed to the macro `loopy--wrap-variables-around-body'."))
 Some iteration commands (e.g., `reduce') will change their behavior
 depending on whether the accumulation variable is given an initial
 value."
-  (or (cl-loop for (var val) in loopy--with-vars
-               when (eq var var-name)
-               return (cons 'with val))
-      (cl-loop for x in loopy--without-vars
-               when (eq x var-name)
-               return (cons 'without nil))))
+  (or (memq var-name (car-safe loopy--with-vars))
+      (memq var-name loopy--without-vars)))
 
 (defun loopy--command-bound-p (var-name)
   "Whether VAR-NAME was bound by a command (and not a special macro argument).
